@@ -6,7 +6,7 @@
     Test fixtures and what not
 """
 
-from datetime import timedelta
+import logging
 
 import pytest
 
@@ -14,11 +14,17 @@ from flask import Flask
 
 import flask_jwt
 
+logging.basicConfig(level=logging.DEBUG)
+
 
 class User(object):
-    def __init__(self, **kwargs):
-        for k, v in kwargs.items():
-            setattr(self, k, v)
+    def __init__(self, id, username, password):
+        self.id = id
+        self.username = username
+        self.password = password
+
+    def __str__(self):
+        return "User(id='%s')" % self.id
 
 
 @pytest.fixture(scope='function')
@@ -36,9 +42,6 @@ def app(jwt, user):
     app = Flask(__name__)
     app.debug = True
     app.config['SECRET_KEY'] = 'super-secret'
-    app.config['JWT_EXPIRATION_DELTA'] = timedelta(milliseconds=200)
-
-    jwt.init_app(app)
 
     @jwt.authentication_handler
     def authenticate(username, password):
@@ -46,11 +49,13 @@ def app(jwt, user):
             return user
         return None
 
-    @jwt.user_handler
+    @jwt.identity_handler
     def load_user(payload):
-        if payload['user_id'] == user.id:
+        if payload['identity'] == user.id:
             return user
 
+    jwt.init_app(app)
+
     @app.route('/protected')
     @flask_jwt.jwt_required()
     def protected():
